#!/usr/bin/env python

"""
Import MITAB data into a relational database system, or apply other database
templates to a database in order to import or export data.

--------

Copyright (C) 2009, 2010, 2011 Ian Donaldson <ian.donaldson@biotek.uio.no>
Original author: Paul Boddie <paul.boddie@biotek.uio.no>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import os, tempfile

def substitute(s, defs):
    for name, value in defs.items():
        s = s.replace("<%s>" % name, value)
    return s

def execute_command(cmd, database_name):
    fd, cmd_filename = tempfile.mkstemp()
    try:
        fc = os.fdopen(fd, "w")
        try:
            fc.write(cmd)
        finally:
            fc.close()
        print cmd
        if os.system("""psql -f %s %s""" % (cmd_filename, database_name)):
            sys.exit(1)
    finally:
        os.remove(cmd_filename)

if __name__ == "__main__":
    import sys, os

    if len(sys.argv) < 3:
        print sys.argv[0], "<database> <template> [ <data_directory> ] [ --defs ( <name> <value> ) ... ]"
        sys.exit(1)

    database_name = sys.argv[1]
    template = sys.argv[2]
    d, filename = os.path.split(sys.argv[0])

    try:
        defs_start = sys.argv.index("--defs")
    except ValueError:
        defs_start = None

    if len(sys.argv) > 3 and defs_start != 3:
        data_directory = sys.argv[3]
    else:
        data_directory = "data"

    sql_directory = os.path.join(d, "sql")

    defs = {}
    if defs_start is not None:
        for i in range(defs_start + 1, len(sys.argv), 2):
            defs[sys.argv[i]] = sys.argv[i+1]

    defs["directory"] = os.path.abspath(data_directory)
    defs["templates"] = os.path.abspath(sql_directory)
    template = os.path.join(d, template)

    f = open(template)
    try:
        cmd = f.read()
        cmd = substitute(cmd, defs)
        execute_command(cmd, database_name)
    finally:
        f.close()

# vim: tabstop=4 expandtab shiftwidth=4
