-- Interactions

create table mitab_interactions (
    uidA varchar not null,            -- column 33 (specific)
    uidB varchar not null,            -- column 34 (specific)
    Atype varchar not null,           -- column 21
    Btype varchar not null,           -- column 22
    rigid varchar not null,           -- column 35 (specific)
    edgetype char(1) not null,        -- column 53
    numParticipants integer not null, -- column 54
    crogidA varchar,                  -- column 46 (canonical)
    crogidB varchar,                  -- column 47 (canonical)
    crigid varchar,                   -- column 48 (canonical)
    primary key(rigid, uidA, uidB)
);

-- Genes related to interactors.
-- Only specific interactors in MITAB2.5 are supported here.

create table mitab_interactor_genes (
    "uid" varchar not null,           -- column 1 or 2 (MITAB2.5)
    entrezGene integer,               -- column 16 or 17 (MITAB2.5)
    primary key("uid", entrezGene)
);

-- Integer identifiers related to interactors.

create table mitab_interactor_rogs (
    "uid" varchar not null,           -- column 33 or 34 (specific)
    rog integer not null,             -- column 43 or 44 (specific)
    primary key("uid", rog)
);

create table mitab_canonical_interactor_rogs (
    "uid" varchar not null,           -- column 46 or 47 (canonical)
    rog integer not null,             -- column 49 or 50 (canonical)
    primary key("uid", rog)
);

-- Integer identifiers related to interactions.

create table mitab_interaction_rigs (
    "uid" varchar not null,           -- column 35 (specific)
    rig integer not null,             -- column 45 (specific)
    primary key("uid", rig)
);

create table mitab_canonical_interaction_rigs (
    "uid" varchar not null,           -- column 48 (canonical)
    rig integer not null,             -- column 51 (canonical)
    primary key("uid", rig)
);

-- Taxonomy identifiers (columns 10 and 11)
-- Only specific interactor taxonomy details are supported here.

create table mitab_interactor_taxonomy (
    "uid" varchar not null,           -- column 33 or 34
    taxid integer,                    -- column 10 or 11 (part, converted)
    primary key("uid", taxid)
);

-- Alternatives (columns 3 and 4)
-- Only specific interactors are supported here.

create table mitab_alternatives (
    "uid" varchar not null,           -- column 33 or 34
    dbname varchar not null,          -- column 3 or 4 (part)
    alt varchar not null,             -- column 3 or 4 (part)
    primary key("uid", dbname, alt)
);

-- Aliases (columns 5 and 6)
-- Only specific interactors are supported here.

create table mitab_aliases (
    "uid" varchar not null,           -- column 33 or 34
    dbname varchar not null,          -- column 5 or 6 (part)
    alias varchar not null,           -- column 5 or 6 (part)
    primary key("uid", dbname, alias)
);

-- Method names (column 7)
-- Only specific interactions are supported here.

create table mitab_method_names (
    rigid varchar not null,           -- column 35
    code varchar not null,            -- column 7 (part)
    name varchar not null,            -- column 7 (part)
    primary key(rigid, code, name)
);

-- Authors (column 8)
-- Only specific interactions are supported here.

create table mitab_authors (
    rigid varchar not null,           -- column 35
    author varchar not null,          -- column 8
    primary key(rigid, author)
);

-- PubMed references (column 9)
-- Only specific interactions are supported here.

create table mitab_pubmed (
    rigid varchar not null,           -- column 35
    pmid integer not null,            -- column 9 (converted)
    primary key(rigid, pmid)
);

-- Interaction type names (column 12)
-- Only specific interactions are supported here.

create table mitab_interaction_type_names (
    rigid varchar not null,           -- column 35
    code varchar not null,            -- column 12 (part, only when available)
    name varchar not null,            -- column 12 (part, only when available)
    primary key(rigid, code, name)
);

-- Sources (column 13)
-- Only specific interactions are supported here.

create table mitab_sources (
    rigid varchar not null,           -- column 35
    sourcedb varchar not null,        -- column 13 (part, ophid is 'MI:0000')
    name varchar not null,            -- column 13 (part)
    primary key(rigid, name)
);

-- Source interactions (column 14)
-- Only specific interactions are supported here.

create table mitab_interaction_identifiers (
    rigid varchar not null,           -- column 35
    dbname varchar not null,          -- column 14 (part)
    "uid" varchar not null,           -- column 14 (part)
    primary key(rigid, dbname, "uid")
);

-- Confidence scores (column 15)
-- Only specific interactions are supported here.

create table mitab_confidence (
    rigid varchar not null,           -- column 35
    "type" varchar not null,          -- column 15 (part)
    confidence integer not null,      -- column 15 (part, converted)
    primary key(rigid, "type", confidence)
);
